# built-in
from datetime import datetime
from distutils.log import debug
import os

# third-party
import numpy as np

from epibox import config_debug


def write_file(t, a_file, sync_param, time, fmt):
    write_acq_file(a_file, t, time, fmt)


def write_acq_file(a_file, t, time, fmt):
	np.savetxt(a_file, t, fmt=fmt, delimiter='	', newline='\n', header='', footer='', comments ='')


def write_drift_log(filename, sync_param):
    
    sync_time = sync_param['sync_time']
    
    if not sync_param['mode']:
        filename.write('%s' % sync_time + '\n')
        sync_param['mode'] = 1
    else:
        filename.write('\n')
    
    # config_debug.log(('%s' % '  ' + sync_time))


def write_annot_file(recording_name, annot):

    with open(os.path.join(os.path.split(recording_name)[0], 'annotations' + '.txt'), 'a+') as file:
        file.write(f'{os.path.split(recording_name)[1]}    {annot[0]}    {annot[1]}    {datetime.now()}\n')



def write_summary_file(recording_name):
    
    duration = datetime.now() - datetime.strptime(os.path.split(recording_name)[1][1:-4], '%Y-%m-%d %H-%M-%S')
    config_debug.log(f'duration: {str(duration)}')

    with open(os.path.join(os.path.split(recording_name)[0], 'summary' + '.txt'), 'a+') as file:
        file.write('{}  {}\n'.format(os.path.split(recording_name)[1], str(duration).split('.')[0]))


# local
from epibox import config_debug
from epibox.common.close_file import close_file


def disconnect_system(devices, a_file=None, files_open=True, devices_connected=True):

    if devices_connected:
        for device in devices:
            try:
                device.stop()
                device.close()

            except:
                continue

    if files_open:
        close_file(a_file)





# built-in
import time
import sys
from datetime import datetime

# third-party
import numpy as np
from epibox import config_debug

# local 
from epibox.common.read_modules import read_modules
from epibox.common.write_file import write_file
from epibox.exceptions.exception_manager import kill_after_duration


def run_system(devices, a_file, sync_param, directory, mac_channels, sensors, fs, save_raw, service, save_fmt, header, client):
    
    # Read batch of samples from the devices and save to the active session's file  ===============================

    if time.time()-sync_param['strtime'] > 5:

        sync_param['strtime'] = time.time()
    
    for i,device in enumerate(devices):
        sync_param['sync_arr_'+chr(ord('@')+i+1)] = np.zeros(1000, dtype = float)
    
    now = datetime.now()
    sync_param['sync_time'] = now.strftime("%Y-%m-%d %H:%M:%S.%f")

    # read batch of samples from devices
    t, t_str, t_display = read_modules(devices, mac_channels, sensors, header)    

    i = time.time() - sync_param['inittime']

    # config_debug.log elapsed time
    sys.stdout.write("\rElapsed time (seconds): % i " % i)
    sys.stdout.flush()
    
    # Write batch of samples to file
    write_file(t, a_file, sync_param, str(i), save_fmt)

    # Open new file each hour
    if sync_param['close_file'] == 1:
        kill_after_duration(client, devices, a_file)

    return t, t_display, a_file, sync_param



import importlib.resources as pkg_resources
import json
import ast

from epibox import common


def get_default(username):

    try:
        with open(
            "/home/{}/Documents/epibox/args.json".format(username), "r"
        ) as json_file:
            defaults = json_file.read()
            defaults = ast.literal_eval(defaults)

    except Exception as e:  # the first time using EpiBOX Core, there will be no default file
        defaults = ast.literal_eval(
            pkg_resources.read_text(common, "default_args.json")
        )

        with open(
            "/home/{}/Documents/epibox/args.json".format(username), "w+"
        ) as json_file:
            json.dump(defaults, json_file)

    return defaults



# built-in
import string 
import random

# third-party
import bitalino

# local
from epibox import config_debug


def random_str(length):

    letters = string.ascii_letters
    return ''.join(random.choice(letters) for i in range(length))


def connect_device(macAddress, client, devices):
    
    connected = False
    devices = [d for d in devices if d] # remove None
    config_debug.log(f'devices: {devices}')
    
    if macAddress in [d.macAddress for d in devices]:
        try:
            config_debug.log(f'{macAddress} state: {[d.state()for d in devices if d.macAddress==macAddress]}')
            config_debug.log(f'{macAddress} state: {[d.state()for d in devices if d.macAddress==macAddress]}')
            connected = True
        
        except Exception as e:
            del devices[[d.macAddress for d in devices].index(macAddress)]
    
    else:

        try: 
            device = bitalino.BITalino(macAddress, timeout=5)
            
            devices += [device]
        except Exception as e:
            config_debug.log(e)
                                
        if macAddress in [d.macAddress for d in devices]:
            connected = True


    devices = [d for d in devices if d] # remove None

    if not connected or macAddress not in [d.macAddress for d in devices]:
        client.publish(topic='rpi', qos=2, payload="['MAC STATE', '{}', '{}']".format(macAddress, 'failed'))

    else:
        client.publish(topic='rpi', qos=2, payload="['MAC STATE', '{}', '{}']".format(macAddress, 'connected'))
    
    return connected, devices


# built-in
from datetime import datetime
import os

# local
from epibox.bit.header2bitalino import header2bitalino


def open_file(directory, devices, mac_channels, sensors, fs, save_raw, service):

    # for txt format
    now = datetime.now()
    save_time = now.strftime("%Y-%m-%d %H-%M-%S").rstrip("0")
    file_time = now.strftime("%Y-%m-%d %H:%M:%S.%f").rstrip("0")
    file_time = file_time[11:]
    file_time = '"' + file_time + '"'
    file_date = '"' + save_time[0:10] + '"'

    a_file = open(os.path.join(directory, "A" + save_time + ".txt"), "w")  # data file

    # create header for the acquisition file
    save_fmt, header = header2bitalino(
        a_file,
        file_time,
        file_date,
        devices,
        mac_channels,
        sensors,
        fs,
        save_raw,
        service,
    )

    return a_file, save_fmt, header



# built-in
import json
from time import sleep

# local
from epibox.bit.manage_devices import pause_devices, connect_devices, start_devices
from epibox.exceptions.exception_manager import (
    error_disconnect,
    error_kill,
    client_kill,
)
from epibox.common.setup import setup_client, setup_config, setup_variables
from epibox.common.create_folder import create_folder
from epibox.common.open_file import open_file
from epibox.common.write_file import write_annot_file
from epibox.common.run_system import run_system
from epibox.common import process_data
from epibox import config_debug


# ****************************** MAIN SCRIPT ***********************************
# This is the main script. It is lauched by EpiBOX Core, through the epibox_startup.sh Bash script.

# This script attempts to connect to the default biosignal acquisition devices in a continuous loop.
# The loop stops only if:
#       - connection is successful
#       - timeout is achieved (2min)

# If timeout, the script ends (being later lauched again by EpiBOX Core)
# If connection is successful, acquisition starts and PyEpiBOX receives and handles data from the
# acquisition devices.
# The loop stops only if:
#       - user stops the acquisition
#       - at least one of the devices disconnects


def main():

    devices = []

    try:
        # Setup MQTT client | read default configurations | initiate variables ===========================
        client = setup_client()
        opt, channels, sensors, service, save_raw = setup_config(client)

        t_all, already_notified_pause, system_started, files_open = setup_variables()

        # Create folder with patient ID
        directory = create_folder(
            opt["initial_dir"], "{}".format(opt["patient_id"]), service
        )
        already_timed_out = False

        # Start loop to connect PyEpiBOX to acquisition devices =========================================
        devices = connect_devices(
            client, devices, opt, already_timed_out, files_open=False
        )

    except Exception as e:
        sleep(3)
        error_kill(
            client,
            devices,
            msg="Failed initial setup",
            files_open=False,
            devices_connected=False,
        )

    try:
        # Open acquisition file | get format and header info ============================================
        a_file, save_fmt, header = open_file(
            directory, devices, channels, sensors, opt["fs"], save_raw, service
        )
        files_open = True

    except Exception as e:
        error_kill(client, devices, msg="Failed to open the files", files_open=False)

    # Starting acquisition loop ===========================================================================
    # This loop runs continuously unless the user stops the acquisition on the EpiBOX App or at least one of
    # the devices disconnects
    try:
        while client.keepAlive == True:

            if client.newAnnot != None:
                # Write user annotation to file if one is received via MQTT ===============================
                config_debug.log(f"annot: {client.newAnnot}")
                write_annot_file(a_file.name, client.newAnnot)
                client.newAnnot = None

            config_debug.log("im here")
            if client.pauseAcq and not already_notified_pause:
                # Pause acquisition if command is received via MQTT ========================================
                devices = pause_devices(client, devices)
                already_notified_pause = True

            elif not client.pauseAcq:

                if already_notified_pause:
                    client.publish("rpi", str(["RECONNECTING"]))
                    already_notified_pause = False

                if not system_started:
                    # If the devices have not yet started acquiring or they are paused, start acquisition
                    try:
                        sync_param = start_devices(
                            client, devices, opt["fs"], channels, header
                        )
                        system_started = True
                        already_timed_out = False

                    except Exception as e:
                        config_debug.log(e)
                        pass

                try:
                    # Read batch of samples from the acquisition devices and store on the active session's file
                    _, t_disp, a_file, sync_param = run_system(
                        devices,
                        a_file,
                        sync_param,
                        directory,
                        channels,
                        sensors,
                        opt["fs"],
                        save_raw,
                        service,
                        save_fmt,
                        header,
                        client,
                    )

                    # Subsample batch of samples and send to the EpiBOX App for visualization purposes ==========
                    t_display = process_data.decimate(t_disp, opt["fs"])
                    t_all += t_display[0]
                    json_data = json.dumps(["DATA", t_display, channels, sensors])
                    client.publish("rpi", json_data)

                    already_timed_out = False

                # Handle misconnection of the devices ============================================================
                except Exception as e:
                    devices, system_started = error_disconnect(
                        client, devices, e, a_file
                    )
                    devices = connect_devices(
                        client, devices, opt, already_timed_out, a_file
                    )
                    system_started = False
                    a_file, save_fmt, header = open_file(
                        directory,
                        devices,
                        channels,
                        sensors,
                        opt["fs"],
                        save_raw,
                        service,
                    )

            else:
                pass

        client_kill(
            client, devices, "You have stopped the acquisition", a_file, files_open
        )

    except KeyboardInterrupt:
        client_kill(
            client, devices, "You have stopped the acquisition", a_file, files_open
        )

    # =========================================================================================================



# built-in
import ast
import os
import subprocess
import json
import shutil
import pwd

# local
from epibox import config_debug
from epibox.common.get_defaults import get_default


def send_default(client, username):

    ######## Available drives ########

    listDrives = ["DRIVES"]
    drives = os.listdir("/media/{}/".format(username))

    for drive in drives:
        total, _, free = shutil.disk_usage("/media/{}/{}".format(username, drive))
        listDrives += ["{} ({:.1f}% livre)".format(drive, (free / total) * 100)]

    client.publish(topic="rpi", qos=2, payload="{}".format(listDrives))

    ######## Default MAC addresses ########

    defaults = get_default(username)
    listMAC = defaults["devices_mac"]
    listMAC2 = json.dumps(
        [
            "DEFAULT MAC",
            "{}".format(list(listMAC.values())[0]),
            "{}".format(list(listMAC.values())[1]),
        ]
    )

    client.publish(topic="rpi", qos=2, payload=listMAC2)
    config = json.dumps(["DEFAULT CONFIG", defaults])
    client.publish(topic="rpi", qos=2, payload=config)


def on_message(client, userdata, message):

    username = pwd.getpwuid(os.getuid())[0]
    message = str(message.payload.decode("utf-8"))
    message = ast.literal_eval(message)

    if message[0] == "RESTART":
        # client.loop_stop()
        # client.keepAlive = False
        config_debug.log("Not sure what to do here yet")

    elif message[0] == "INTERRUPT":
        client.keepAlive = False

    elif message[0] == "PAUSE ACQ":
        config_debug.log("PAUSING ACQUISITION")
        client.pauseAcq = True

    elif message[0] == "RESUME ACQ":
        config_debug.log("RESUMING ACQUISITION")
        client.pauseAcq = False

    elif message[0] == "ANNOTATION":
        config_debug.log("RECEIVED ANNOT {} ----------------------".format(message[1]))
        client.newAnnot = message[1]

    elif message[0] == "TURN OFF":
        config_debug.log("TURNING OFF RPI")
        client.publish(topic="rpi", payload=str(["TURNED OFF"]))

    elif message[0] == "TURNED OFF":
        subprocess.run(["sudo", "shutdown", "-h", "now"])

    elif message == ["Send default"]:
        send_default(client, username)

    ######## New default configuration ########

    elif message[0] == "NEW CONFIG DEFAULT":
        defaults = get_default(username)

        for key in message[1].keys():
            defaults[key] = message[1][key]

        with open(
            "/home/{}/Documents/epibox/args.json".format(username), "w+"
        ) as json_file:
            json.dump(defaults, json_file)

        msg = json.dumps(["RECEIVED DEFAULT"])
        client.publish(topic="rpi", qos=2, payload=msg)



# built-in
import subprocess
import time

# local
from epibox.common.disconnect_system import disconnect_system
from epibox.common.write_file import write_summary_file
from epibox import config_debug


def error_kill(
    client,
    devices,
    msg,
    mqtt_msg="ERROR",
    a_file=None,
    files_open=True,
    devices_connected=True,
):

    config_debug.log(msg)
    client.publish("rpi", str([mqtt_msg]))
    client.loop_stop()

    # Disconnect the system
    disconnect_system(devices, a_file, files_open, devices_connected)

    pid = subprocess.run(
        ["sudo", "pgrep", "python"], capture_output=True, text=True
    ).stdout.split("\n")[:-1]
    for p in pid:
        subprocess.run(["kill", "-9", p])

    config_debug.log("killed")


def error_disconnect(client, devices, msg, a_file=None, files_open=True):

    config_debug.log("The system has stopped running because " + str(msg))
    client.publish("rpi", str(["RECONNECTING"]))

    # Disconnect the system
    write_summary_file(a_file.name)
    disconnect_system(devices, a_file, files_open)

    devices = []
    system_started = False

    return devices, system_started


def kill_after_duration(client, devices, a_file=None, files_open=True):

    client.publish("rpi", str(["STOPPED"]))
    client.loop_stop()

    # Disconnect the system
    write_summary_file(a_file.name)
    disconnect_system(devices, a_file, files_open)

    pid = subprocess.run(
        ["sudo", "pgrep", "python"], capture_output=True, text=True
    ).stdout.split("\n")[:-1]
    for p in pid:
        subprocess.run(["kill", "-9", p])


def client_kill(client, devices, msg, a_file=None, files_open=True):

    config_debug.log(msg)
    client.publish("rpi", str(["STOPPED"]))
    client.loop_stop()

    # Disconnect the system
    disconnect_system(devices, a_file, files_open)

    pid = subprocess.run(
        ["sudo", "pgrep", "python"], capture_output=True, text=True
    ).stdout.split("\n")[:-1]
    for p in pid:
        subprocess.run(["kill", "-9", p])



from epibox import config_debug


def header2bitalino(
    filename,
    file_time,
    file_date,
    devices,
    mac_channels,
    sensors,
    fs,
    save_raw,
    service,
):

    filename.write("# OpenSignals Text File Format" + "\n")

    mac_dict = {}
    resolution = {}
    fmt = []  # get format to save values in txt

    for n_device, device in enumerate(devices):

        fmt += ["%i"]
        mac_dict[device.macAddress] = {}
        mac_dict[device.macAddress]["sensor"] = []
        for i, elem in enumerate(mac_channels):
            if elem[0] == device.macAddress:
                mac_dict[device.macAddress]["sensor"] += [sensors[i]]
                if save_raw:
                    fmt += ["%i"]
                else:
                    fmt += ["%.2f"]
        mac_dict[device.macAddress]["device name"] = "Device " + str(n_device + 1)

        aux = ["A" + elem[1] for elem in mac_channels if elem[0] == device.macAddress]
        mac_dict[device.macAddress]["column"] = ["nSeq"] + aux

        mac_dict[device.macAddress]["sync interval"] = 2  # ???

        mac_dict[device.macAddress]["start time"] = file_time
        mac_dict[device.macAddress]["device connection"] = device.macAddress

        mac_dict[device.macAddress]["channels"] = [
            int(elem[1]) for elem in mac_channels if elem[0] == device.macAddress
        ]

        mac_dict[device.macAddress]["date"] = file_date
        # mac_dict[device.macAddress]["firmware version"] = device.version()

        if service == "Bitalino":
            mac_dict[device.macAddress]["device"] = "bitalino_rev"
        else:
            mac_dict[device.macAddress]["device"] = "bitalino_mini"

        mac_dict[device.macAddress]["sampling rate"] = fs

        if save_raw:
            mac_dict[device.macAddress]["label"] = [
                "RAW"
                for i, elem in enumerate(mac_channels)
                if elem[0] == device.macAddress
            ]
        else:
            mac_dict[device.macAddress]["label"] = [
                sensors[i]
                for i, elem in enumerate(mac_channels)
                if elem[0] == device.macAddress
            ]
        aux = [10, 10, 10, 10, 6, 6]
        aux2 = [1 for elem in mac_channels if elem[0] == device.macAddress]
        mac_dict[device.macAddress]["resolution"] = [4] + [
            aux[i] for i in range(len(aux2))
        ]
        resolution[device.macAddress] = mac_dict[device.macAddress]["resolution"]

    header = {"resolution": resolution, "save_raw": save_raw, "service": service}

    config_debug.log(f"# {mac_dict} \n")
    filename.write("# " + str(mac_dict) + "\n")
    filename.write("# EndOfHeader" + "\n")

    return tuple(fmt), header



# built-in
import json

#local
from epibox import config_debug 


def get_battery(client, devices, service):

    if service != 'Mini':
        try:
            battery = {}
            for device in devices:
                state = device.state()
                if state['battery'] > 63:
                    battery_volts = 2 * ((state['battery']*3.3) / (2**10-1))
                else:
                    battery_volts = 2 * ((state['battery']*3.3) / (2**6-1))

                battery[device.macAddress] = battery_volts

            battery_json = json.dumps(['BATTERY', battery])
            client.publish('rpi', battery_json)

        except Exception as e:
            config_debug.log(e)
            pass


# built-in
from copy import copy

# third-party
import numpy as np

from epibox import config_debug



def read_modules(devices, mac_channels, sensors, header):

    
    t = np.array([])
    t_display = np.array([])
    # 
    # config_debug.log('devices: {}'.format([d.macAddress for d in devices]))
    channels2get = [int(mac_chn[1])-1 for mac_chn in mac_channels]
        
    for i, device in enumerate(devices):

        t_read = device.read(100)

        if header['service'] == 'Bitalino' or header['service'] == 'Mini':
            t_read = np.delete(t_read, np.arange(1,5), axis=1) # remove digital channels
            t_nseq = t_read[:,1:] # remove nSeq column (add again in the end)

        else:
            seq = []
            t_nseq = []
            
            for f in t_read:

                frame = f.toMap()
                seq += [frame['sequence']]

                if len(t_nseq) == 0:
                    t_nseq_aux = np.reshape(np.array(frame['analog']), (1,-1))
                    t_nseq = np.reshape(np.take(t_nseq_aux, channels2get), (1,-1))
                else:
                    t_nseq_aux = np.reshape(np.take(np.reshape(np.array(frame['analog']), (1,-1)), channels2get), (1,-1))
                    t_nseq = np.vstack((t_nseq, t_nseq_aux))

            t_read = np.hstack((np.reshape(np.array(seq), (-1,1)), t_nseq))

        #config_debug.log(t_read)

        n = 0
        display_aux = np.array([])

        for j,chn in enumerate(mac_channels):

            if chn[0] == device.macAddress:

                if header['save_raw']:
                    signal_type = 'RAW'

                else:
                    signal_type = sensors[j]

                r = header['resolution'][device.macAddress][n+1]
                t_aux = get_transform(t_nseq[:,n], signal_type, r) # receives and returns a column with 100 samples

                n += 1
                if len(display_aux) == 0:
                    display_aux = copy(t_aux)

                else:
                    display_aux = np.concatenate((display_aux, t_aux), axis=1)

  
        if len(t_display) == 0:
            t_display = copy(display_aux)
            t = np.concatenate((np.reshape(t_read[:,0], (-1,1)), display_aux), axis=1)

        else:
            t_display = np.concatenate((t_display, display_aux), axis=1)
            aux = np.concatenate((np.reshape(t_read[:,0], (-1,1)), display_aux), axis=1)
            t = np.concatenate((t, aux), axis=1)

    t_str = '\n'.join(' '.join('%0.1f' %x for x in y) for y in t)
    return t, t_str, t_display



def get_transform(raw, signal_type, res):

    if signal_type == 'ECG':
        aux = list(map(lambda x: (((x/(2**res)-0.5)*3.3)/1100)*1000, raw))

    elif signal_type == 'EEG':
        aux = list(map(lambda x: (((x/(2**res)-0.5)*3.3)/41782)*(10**(6)), raw))

    elif signal_type == 'EOG':
        aux = list(map(lambda x: (((x/(2**res)-0.5)*3.3)/2040)*1000, raw))

    elif signal_type == 'EMG':
        aux = list(map(lambda x: (((x/(2**res)-0.5)*3.3)/1009)*1000, raw))

    elif signal_type == 'PZT':
        aux = list(map(lambda x: (x/(2**res)-0.5)*100, raw))

    elif signal_type == 'EDA':
        aux = list(map(lambda x: (((x/(2**res))*3.3)/0.132), raw))

    else:
        aux = list(raw)

    return np.reshape(np.asarray(aux), (-1,1))

        




#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open("README.md") as readme_file:
    readme = readme_file.read()

with open("HISTORY.rst") as history_file:
    history = history_file.read()


test_requirements = []

setup(
    author="Ana Sofia Carmo",
    author_email="anascacais@gmail.com",
    python_requires=">=3.6",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    description="EpiBOX is a Raspberry Pi tool for easy signal acquisition.",
    entry_points={
        "console_scripts": [
            "epibox=epibox.cli:main",
        ],
    },
    install_requires=[
        "alabaster==0.7.12",
        "appdirs==1.4.4",
        "argh==0.26.2",
        "arrow==1.1.1",
        "Babel==2.9.1",
        "binaryornot==0.4.4",
        "bitalino==1.2.1",
        "bleach==3.3.0",
        "certifi==2021.5.30",
        "chardet==4.0.0",
        "click",
        "colorama==0.4.4",
        "cookiecutter==1.7.3",
        "distlib==0.3.2",
        "docutils==0.17.1",
        "entrypoints==0.3",
        "filelock==3.0.12",
        "idna==2.10",
        "imagesize==1.2.0",
        "install==1.3.4",
        "Jinja2==3.0.1",
        "jinja2-time==0.2.0",
        "MarkupSafe==2.0.1",
        "mccabe==0.6.1",
        "numpy==1.21.0",
        "packaging==21.0",
        "paho-mqtt==1.5.1",
        "pathtools==0.1.2",
        "pexpect==4.8.0",
        "pkginfo==1.7.0",
        "pluggy",
        "poyo==0.5.0",
        "primefac==1.1",
        "ptyprocess==0.7.0",
        "py==1.10.0",
        "pybluez2==0.41",
        "pycodestyle==2.5.0",
        "pyflakes==2.1.1",
        "Pygments==2.9.0",
        "pyparsing==2.4.7",
        "pyserial==3.5",
        "python-dateutil==2.8.1",
        "python-slugify==5.0.2",
        "pytz==2021.1",
        "PyYAML==5.4.1",
        "readme-renderer==29.0",
        "requests==2.25.1",
        "requests-toolbelt==0.9.1",
        "scipy==1.7.0",
        "six==1.16.0",
        "snowballstemmer==2.1.0",
        "Sphinx==1.8.5",
        "sphinxcontrib-serializinghtml==1.1.5",
        "sphinxcontrib-websupport==1.2.4",
        "text-unidecode==1.3",
        "toml==0.10.2",
        "tox",
        "tqdm==4.61.2",
        "twine",
        "urllib3==1.26.6",
        "virtualenv==20.4.7",
        "watchdog==0.9.0",
        "webencodings==0.5.1",
    ],
    license="MIT license",
    long_description_content_type="text/markdown",
    long_description=readme + "\n\n" + history,
    include_package_data=True,
    keywords=["epibox", "signal acquisition", "Raspberry Pi"],
    name="epibox",
    packages=find_packages(include=["epibox", "epibox.*"]),
    test_suite="tests",
    tests_require=test_requirements,
    url="https://github.com/anascacais/epibox",
    version="1.1.10",
    zip_safe=False,
)



import os

from epibox import config_debug


def create_folder(initial_dir, nb, service):
    
    # Create folder with patient ID unless it already exists
    directory = os.path.join(initial_dir, nb)
    directory = os.path.join(directory, service)
    
    if not os.path.exists(directory):
        os.makedirs(directory)
        config_debug.log(f'Created patient directory -- {directory}')
            
    else:
        config_debug.log(f'Directory -- {directory} -- already exists')

    return directory



# bult-in
import subprocess
import bluetooth

passkey = "1234"
addr = '98:D3:91:FD:3F:5C'

#subprocess.call("kill -9 `pidof bluetooth-agent`",shell=True)
status = subprocess.call("bluetooth-agent " + passkey + " &",shell=True)

try:
    s = bluetooth.BluetoothSocket(bluetooth.RFCOMM)
    s.connect((addr, 1))
except bluetooth.btcommon.BluetoothError as err:
    # Error handler
    pass